'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _babelTypes = require('babel-types');

var _babelLiteralToAst = require('babel-literal-to-ast');

var _babelLiteralToAst2 = _interopRequireDefault(_babelLiteralToAst);

var _graphqlTag = require('graphql-tag');

var _graphqlTag2 = _interopRequireDefault(_graphqlTag);

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const debug = (0, _debug2.default)('babel-plugin-graphql-tag');

exports.default = () => {
  const compile = node => {
    const source = node.quasis.reduce((head, quasi) => {
      return head + quasi.value.raw;
    }, '');

    debug('compiling a GraphQL query', source);

    const queryDocument = (0, _graphqlTag2.default)(source);

    for (const definition of queryDocument.definitions) {
      if (!definition.name) {
        throw new Error('GraphQL query must have name.');
      }
    }

    const body = (0, _babelLiteralToAst2.default)(queryDocument);

    debug('created a static representation', body);

    return body;
  };

  return {
    visitor: {
      ImportDeclaration(path) {
        if (path.node.source.value === 'graphql-tag') {
          path.remove();
        }
      },
      TaggedTemplateExpression(path) {
        if ((0, _babelTypes.isIdentifier)(path.node.tag, {
          name: 'gql'
        })) {
          try {
            debug('quasi', path.node.quasi);

            const body = compile(path.node.quasi);

            path.replaceWith(body);
          } catch (error) {
            // eslint-disable-next-line no-console
            console.error('error', error);
          }
        }
      }
    }
  };
};
//# sourceMappingURL=index.js.map